@@ -28,7 +28,7 @@ def act__signup(name: str = None, pw: str = None) -> dict:
     if pw is None:
         pw = 'password'
     resp = post__signup(name, pw, ATestRequest(True))
-    assert resp[AA.HttpStatus] == HttpStatus.Created_201
+    assert resp[AA.HttpStatus] == HttpStatus.Created_201.value
     uid: str = resp[AA.Data][AA.UserId]
     return {
         AA.Name: name,
